package com.qmth.ops.api.controller.admin;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.qmth.ops.api.constants.OpsApiConstants;
import com.qmth.ops.api.security.AdminSession;
import com.qmth.ops.biz.domain.*;
import com.qmth.ops.biz.query.AppQuery;
import com.qmth.ops.biz.service.AppService;
import com.qmth.ops.biz.service.AppUserService;
import com.qmth.ops.biz.service.UserService;
import com.qmth.ops.biz.service.VersionService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@RestController
@RequestMapping(OpsApiConstants.ADMIN_URI_PREFIX + "/app")
public class AppController {

    @Resource
    private AppService appService;

    @Resource
    private AppUserService appUserService;

    @Resource
    private VersionService versionService;

    @Resource
    private UserService userService;

    @PostMapping("/query")
    public IPage<AppDTO> query(@RequestAttribute AdminSession accessEntity, AppQuery query) {
        User user = accessEntity.getUser();
        if (user.getRole() == Role.DEV || user.getRole() == Role.TEST) {
            query.setUserId(user.getId());
        }
        return appService.query(query);
    }

    @PostMapping("/list")
    public List<AppDTO> list(@RequestAttribute AdminSession accessEntity, AppQuery query) {
        User user = accessEntity.getUser();
        if (user.getRole() == Role.DEV || user.getRole() == Role.TEST) {
            query.setUserId(user.getId());
        }
        return appService.list(query);
    }

    @PostMapping("/insert")
    public AppDTO insert(App app) {
        appService.insert(app);
        return appService.findDTO(app.getId());
    }

    @PostMapping("/update")
    public AppDTO update(App app) {
        appService.update(app);
        return appService.findDTO(app.getId());
    }

    @PostMapping("/version/master")
    public AppDTO updateMasterVersion(@RequestParam Long id, @RequestParam Long versionId) {
        appService.setMasterVersion(appService.getById(id), versionService.getById(versionId));
        return appService.findDTO(id);
    }

    @PostMapping("/user/bind")
    public AppUser bindUser(@RequestParam Long id, @RequestParam Long userId) {
        return appUserService.insert(appService.getById(id), userService.getById(userId));
    }

    @PostMapping("/user/unbind")
    public AppUser unbindUser(@RequestParam Long id, @RequestParam Long userId) {
        appUserService.delete(appService.getById(id), userService.getById(userId));
        return new AppUser(id, userId);
    }
}

